/* Copyright (C) 2000-2002 Lavtech.com corp. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
*/

#ifndef _UDM_DOC_H
#define _UDM_DOC_H

extern __C_LINK UDM_DOCUMENT * __UDMCALL UdmDocInit(UDM_DOCUMENT*);
extern __C_LINK void __UDMCALL UdmDocFree(UDM_DOCUMENT*);
extern int           UdmDocToTextBuf(UDM_DOCUMENT * Doc,char *d,size_t maxlen);
extern __C_LINK int __UDMCALL UdmDocFromTextBuf(UDM_DOCUMENT * Doc,const char *d);

extern void UdmURLCRDListListInit(UDM_URLCRDLISTLIST *Lst);
extern void UdmURLCRDListListFree(UDM_URLCRDLISTLIST *Lst);
extern int UdmURLCRDListListAdd(UDM_URLCRDLISTLIST *Lst, UDM_URLCRDLIST *I);

#endif
